@@ -34,10 +34,12 @@
 
 #include "config.h"
 
+#define CRYPTOKI_EXPORTS
 #include "pkcs11.h"
 #include "mock-module.h"
 
-#include <pthread.h>
+#include "p11-kit/compat.h"
+
 #include <stdarg.h>
 #include <stdio.h>
 #include <string.h>
@@ -48,7 +50,7 @@
  */
 
 /* Various mutexes */
-static pthread_mutex_t init_mutex = PTHREAD_MUTEX_INITIALIZER;
+static mutex_t init_mutex;
 
 /* Whether we've been initialized, and on what process id it happened */
 static int pkcs11_initialized = 0;
@@ -95,7 +97,7 @@ mock_C_Initialize (CK_VOID_PTR init_args)
 
 	debug (("C_Initialize: enter"));
 
-	pthread_mutex_lock (&init_mutex);
+	_p11_mutex_lock (&init_mutex);
 
 		if (init_args != NULL) {
 			int supplied_ok;
@@ -146,7 +148,7 @@ done:
 			pkcs11_initialized_pid = 0;
 		}
 
-	pthread_mutex_unlock (&init_mutex);
+	_p11_mutex_unlock (&init_mutex);
 
 	debug (("C_Initialize: %d", ret));
 	return ret;
@@ -156,16 +158,16 @@ CK_RV
 mock_C_Finalize (CK_VOID_PTR reserved)
 {
 	debug (("C_Finalize: enter"));
-	return_val_if_fail (pkcs11_initialized, CKR_CRYPTOKI_NOT_INITIALIZED);
-	return_val_if_fail (!reserved, CKR_ARGUMENTS_BAD);
+	return_val_if_fail (pkcs11_initialized != 0, CKR_CRYPTOKI_NOT_INITIALIZED);
+	return_val_if_fail (reserved == NULL, CKR_ARGUMENTS_BAD);
 
-	pthread_mutex_lock (&init_mutex);
+	_p11_mutex_lock (&init_mutex);
 
 		/* This should stop all other calls in */
 		pkcs11_initialized = 0;
 		pkcs11_initialized_pid = 0;
 
-	pthread_mutex_unlock (&init_mutex);
+	_p11_mutex_unlock (&init_mutex);
 
 	debug (("C_Finalize: %d", CKR_OK));
 	return CKR_OK;
@@ -884,3 +886,9 @@ CK_FUNCTION_LIST mock_module_no_slots = {
 	mock_C_CancelFunction__not_parallel,
 	mock_C_WaitForSlotEvent__no_event,
 };
+
+void
+mock_module_init (void)
+{
+	_p11_mutex_init (&init_mutex);
+}
